#!/bin/sh

# PROVIDE: zscams
# REQUIRE: NETWORKING
# KEYWORD: shutdown

. /etc/rc.subr

name="zscams"
rcvar="zscams_enable"

command="/usr/sbin/daemon"
command_args="-f -p /var/run/${{name}}.pid -u {user_to_run_as} {python_exec} -m zscams"

pidfile="/var/run/${{name}}.pid"

load_rc_config $name
run_rc_command "$1"
